AST module for HTML nodes.
Html Ast
This module provides html ast functionality for the Oaks project.
Structs
- Attribute
- HTML attribute consisting of a name, an optional value, and its source span.
- Element
- An HTML element consisting of a tag name, attributes, children nodes, and its source span.
- Html
Document - The root node of an HTML document, containing a sequence of top-level nodes.
- Text
- Represents plain text content within an HTML document.
Enums
- Html
Node - Represents different types of nodes in an HTML document.